/// <reference types="node" />
interface CachedFetchValue {
    kind: "FETCH";
    data: {
        headers: {
            [k: string]: string;
        };
        body: string;
        url: string;
        status?: number;
        tags?: string[];
    };
    revalidate: number;
}
interface CachedRedirectValue {
    kind: "REDIRECT";
    props: Object;
}
interface CachedRouteValue {
    kind: "ROUTE";
    body: Buffer;
    status: number;
    headers: Record<string, undefined | string | string[]>;
}
interface CachedImageValue {
    kind: "IMAGE";
    etag: string;
    buffer: Buffer;
    extension: string;
    isMiss?: boolean;
    isStale?: boolean;
}
interface IncrementalCachedPageValue {
    kind: "PAGE";
    html: string;
    pageData: Object;
    status?: number;
    headers?: Record<string, undefined | string>;
}
type IncrementalCacheValue = CachedRedirectValue | IncrementalCachedPageValue | CachedImageValue | CachedFetchValue | CachedRouteValue;
interface CacheHandlerContext {
    fs?: never;
    dev?: boolean;
    flushToDisk?: boolean;
    serverDistDir?: string;
    maxMemoryCacheSize?: number;
    _appDir: boolean;
    _requestHeaders: never;
    fetchCacheKeyPrefix?: string;
}
interface CacheHandlerValue {
    lastModified?: number;
    age?: number;
    cacheState?: string;
    value: IncrementalCacheValue | null;
}
export default class S3Cache {
    private client;
    private dynamoClient;
    private buildId;
    constructor(_ctx: CacheHandlerContext);
    get(key: string, options?: boolean | {
        fetchCache?: boolean;
    }): Promise<CacheHandlerValue | null>;
    getFetchCache(key: string, keys: string[]): Promise<CacheHandlerValue | null>;
    getIncrementalCache(key: string, keys: string[]): Promise<CacheHandlerValue | null>;
    set(key: string, data?: IncrementalCacheValue): Promise<void>;
    revalidateTag(tag: string): Promise<void>;
    private getTagsByPath;
    private getHasRevalidatedTags;
    private getByTag;
    private batchWriteDynamoItem;
    private buildDynamoKey;
    private buildDynamoObject;
    private chunkArray;
    private buildS3Key;
    private buildS3KeyPrefix;
    private listS3Object;
    private getS3Object;
    private putS3Object;
    private deleteS3Objects;
}
export {};
