import fs from "node:fs";
import path from "node:path";
import { isBinaryContentType } from "../binary";
import { ServerlessResponse } from "../http/response";
export function isExternal(url) {
    if (!url)
        return false;
    const pattern = /^https?:\/\//;
    return pattern.test(url);
}
export function getUrlParts(url, isExternal) {
    if (!isExternal) {
        return {
            hostname: "",
            pathname: url,
            protocol: "",
        };
    }
    const { hostname, pathname, protocol } = new URL(url);
    return {
        hostname,
        pathname,
        protocol,
    };
}
export function convertRes(res) {
    // Format Next.js response to Lambda response
    const statusCode = res.statusCode || 200;
    const headers = ServerlessResponse.headers(res);
    const isBase64Encoded = isBinaryContentType(Array.isArray(headers["content-type"])
        ? headers["content-type"][0]
        : headers["content-type"]);
    const encoding = isBase64Encoded ? "base64" : "utf8";
    const body = ServerlessResponse.body(res).toString(encoding);
    return {
        statusCode,
        headers,
        body,
        isBase64Encoded,
    };
}
export function convertQuery(query) {
    const urlQuery = {};
    Object.keys(query).forEach((k) => {
        const v = query[k];
        urlQuery[k] = Array.isArray(v) ? v.join(",") : v;
    });
    return urlQuery;
}
export function getMiddlewareMatch(middlewareManifest) {
    const rootMiddleware = middlewareManifest.middleware["/"];
    if (!rootMiddleware?.matchers)
        return [];
    return rootMiddleware.matchers.map(({ regexp }) => new RegExp(regexp));
}
export function loadMiddlewareManifest(nextDir) {
    const filePath = path.join(nextDir, "server", "middleware-manifest.json");
    const json = fs.readFileSync(filePath, "utf-8");
    return JSON.parse(json);
}
